import "./App.css";
import Widget from "./app/pages/Widget";
import "./app/assets/styles/general.scss";
import "react-voice-recorder/dist/index.css";
import { useEffect } from "react";
import { styled } from "@stitches/react";
import { ReactReduxContext, useDispatch } from "react-redux";
import { fetchWidgetInfoStart, setActiveTriggerMessage, setAnimateWidget, setLuancherContent, setOfficeHoure, setShowLuancher } from "./app/redux/widget/widget.actions";
import { useSelector } from "react-redux";
import { useState } from "react";
import { BrowserRouter as Router, Routes, Route, useLocation } from "react-router-dom";
import "animate.css";
import { setDisableInput, setNewMessage, setOffilneMessage } from "./app/redux/messages/messages.actions";
const MainStyles = styled("div", {});

const mapState = ({
  widgetData,
  messagesData
}) => ({
  widgetInfo: widgetData.widgetInfo,
  messages: messagesData.messages.data
});

function App() {
  const dispatch = useDispatch();
  const {
    widgetInfo,
    messages
  } = useSelector(mapState);
  const [timeAfterLoad, setTimeAfterLoad] = useState(0);
  const [activeTriggerMessages, setActiveTriggerMessages] = useState([]);
  const location = useLocation();

  const getTriggerCondition = (condition, message) => {
    let pageTitle = document.querySelector("title").innerHTML;

    switch (condition.cond) {
      case "1":
        // getTimeCondition();
        if (condition.value == timeAfterLoad) {
          return true;
        }

        break;

      case "2":
        // getAddressCondition();
        switch (condition.eq) {
          case "==":
            if (window.location.href == condition.value) {
              return true;
            }

            break;

          case "!=":
            if (window.location.href != condition.value) {
              return true;
            }

            break;

          case "contains":
            if (window.location.href.includes(condition.value)) {
              return true;
            }

            break;

          case "starts":
            if (window.location.href.startsWith(condition.value)) {
              return true;
            }

            break;

          case "end":
            if (window.location.href.endsWith(condition.value)) {
              return true;
            }

            break;

          case "ncontains":
            if (!window.location.href.includes(condition.value)) {
              return true;
            }

            break;

          default:
            break;
        }

        break;

      case "3":
        // getTitleCondition();
        switch (condition.eq) {
          case "==":
            if (pageTitle == condition.value) {
              return true;
            }

            break;

          case "!=":
            if (pageTitle != condition.value) {
              return true;
            }

            break;

          case "contains":
            if (pageTitle.includes(condition.value)) {
              return true;
            }

            break;

          case "starts":
            if (pageTitle.startsWith(condition.value)) {
              return true;
            }

            break;

          case "end":
            if (pageTitle.endsWith(condition.value)) {
              return true;
            }

            break;

          case "ncontains":
            if (!pageTitle.includes(condition.value)) {
              return true;
            }

            break;

          default:
            break;
        }

        break;

      default:
        break;
    }
  };

  const showAutoMessage = message => {
    switch (message.commands) {
      case "raychat_btn_shake":
        dispatch(setAnimateWidget(true));
        break;

      case "raychat_open_container":
        dispatch(setShowLuancher(true));
        dispatch(setLuancherContent("cover"));
        break;

      case "raychat_close_container":
        dispatch(setShowLuancher(false));
        break;

      case "raychat_send_message":
        dispatch(setActiveTriggerMessage({ ...message,
          message: message.message,
          agent_id: null,
          avatar: null,
          title: message.name,
          isAutoMessage: true
        }));
        break;

      case "raychat_send_message_open":
        dispatch(setShowLuancher(true));
        dispatch(setNewMessage({
          me: false,
          avatar: "",
          type: "text",
          content: message.message
        }));
        break;

      default:
        break;
    }
  };

  const getTriggerMessage = () => {
    let adaptedMessages = activeTriggerMessages;
    adaptedMessages.forEach((message, index) => {
      let conditionsStatus = 0;
      message.conditions.forEach(condition => {
        if (getTriggerCondition(condition, message) === true) {
          conditionsStatus = conditionsStatus + 1;
        }
      });

      if (conditionsStatus === message.conditions.length) {
        showAutoMessage(message);
        let updatedMessages = adaptedMessages.filter(item => {
          return item.id != message.id;
        });
        adaptedMessages = updatedMessages;
      }

      conditionsStatus = 0;
    });
    setActiveTriggerMessages(adaptedMessages);
  };

  useEffect(() => {
    if (widgetInfo.data && timeAfterLoad <= widgetInfo.data.trigger.maxTime) {
      const timer = setInterval(() => {
        getTriggerMessage();
        setTimeAfterLoad(timeAfterLoad + 1);
      }, 1000);
      return () => clearInterval(timer);
    }
  }, [timeAfterLoad]);
  useEffect(async () => {
    if (widgetInfo.data) {
      if (widgetInfo.data.trigger.messages) {
        setActiveTriggerMessages(widgetInfo.data.trigger.messages);
        setTimeAfterLoad(1);
      }
    }
  }, [widgetInfo.data]);
  return widgetInfo.data ? /*#__PURE__*/React.createElement(MainStyles, {
    css: {
      "--primary-color": widgetInfo.data.personalize.bgc,
      "--widget-right-position": widgetInfo.data.personalize.position.rightSpace,
      "--widget-left-position": widgetInfo.data.personalize.position.leftSpace,
      "--widget-bottom-position": widgetInfo.data.personalize.position.bottomSpace,
      "--widget-top-position": widgetInfo.data.personalize.position.topSpace,
      "--trigger-right-position": widgetInfo.data.personalize.position.rightSpace !== "auto" && "75px",
      "--trigger-left-position": widgetInfo.data.personalize.position.leftSpace !== "auto" && "75px",
      "--trigger-top-position": widgetInfo.data.personalize.position.topSpace !== "auto" && "100px",
      "--trigger-bottom-position": widgetInfo.data.personalize.position.bottomSpace !== "auto" && "100px",
      "--luancher-top-position": widgetInfo.data.personalize.position.topSpace !== "auto" && "100px",
      "--luancher-bottom-position": widgetInfo.data.personalize.position.bottomSpace !== "auto" && "100px"
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "App"
  }, /*#__PURE__*/React.createElement(Routes, null, /*#__PURE__*/React.createElement(Route, {
    path: "*",
    element: /*#__PURE__*/React.createElement(Widget, null)
  })))) : /*#__PURE__*/React.createElement(React.Fragment, null);
}

export default App;