import React, { useState } from "react";
import { useEffect } from "react";
import Styles from "./styles/chatForm";
import { useDispatch, useSelector } from "react-redux";
import { sendFormMessage } from "../../redux/messages/messages.actions";
import { IMAGES_BASE_URL, RAYCHAT_MAIN_URL } from "../../utils/urls";
const inputList = [{
  title: "email",
  type: "email",
  placeholder: "ایمیل",
  value: "",
  REGEX: /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,
  error: {
    active: false,
    message: "ایمیل معتبر نیست!"
  }
}, {
  title: "fullName",
  type: "text",
  placeholder: "نام",
  value: ""
}, {
  title: "phone",
  type: "text",
  placeholder: "موبایل",
  value: "",
  REGEX: /^(\+98|0)?9\d{9}$/g,
  error: {
    active: false,
    message: "شماره موبال معتبر نیست!"
  }
}];

const mapStates = ({
  messagesData,
  widgetData
}) => ({
  userformStatus: messagesData.userformStatus,
  coverIcon: widgetData.widgetInfo.data.coverIcon
});

const ChatForm = ({
  message
}) => {
  const [formInputs, setFormInputs] = useState([]);
  const [disableSubmit, setDisableSubmit] = useState(true);
  const {
    userformStatus,
    coverIcon
  } = useSelector(mapStates);
  const dispatch = useDispatch();

  const getFormInputs = () => {
    let adaptedInputs = [];
    message.fields.forEach((item, index) => {
      inputList.forEach((item2, index2) => {
        if (item === item2.title) {
          adaptedInputs.push(item2);
        }
      });
    });
    setFormInputs(adaptedInputs);
  };

  useEffect(() => {
    if (message) {
      getFormInputs();
    }
  }, [message]);

  const fixNumbers = str => {
    let persianNumbers = [/۰/g, /۱/g, /۲/g, /۳/g, /۴/g, /۵/g, /۶/g, /۷/g, /۸/g, /۹/g],
        englishNumbers = [/٠/g, /1/g, /2/g, /3/g, /4/g, /5/g, /6/g, /7/g, /8/g, /9/g];

    if (typeof str === "string") {
      for (var i = 0; i < 10; i++) {
        str = str.replace(persianNumbers[i], i).replace(englishNumbers[i], i);
      }
    }

    return str;
  };

  const handleUserInput = (name, value) => {
    let adaptedInputs = formInputs.map((item, index) => {
      if (item.title === name) {
        return { ...item,
          value: name === "phone" ? fixNumbers(value) : value
        };
      } else {
        return item;
      }
    });
    setFormInputs(adaptedInputs);
  };

  useEffect(() => {
    let disableInputCounts = 0;
    formInputs.forEach(item => {
      if (!item.value || item.value === "") {
        disableInputCounts += 1;
      }
    });

    if (disableInputCounts === 0) {
      setDisableSubmit(false);
    } else {
      setDisableSubmit(true);
    }
  }, [formInputs]);

  const isValidInput = input => {
    const inputRegex = new RegExp(input.REGEX);
    return inputRegex.test(input.value);
  };

  const handleSendForm = () => {
    let isValidForm = true;
    let adaptedInputs = [];
    formInputs.forEach((input, index) => {
      if (input.REGEX && !isValidInput(input)) {
        isValidForm = false;
        adaptedInputs.push({ ...input,
          error: { ...input.error,
            active: true
          }
        });
      } else if (input.REGEX && isValidInput(input)) {
        adaptedInputs.push({ ...input,
          error: { ...input.error,
            active: false
          }
        });
      }
    });
    setFormInputs(adaptedInputs);

    if (isValidForm) {
      dispatch(sendFormMessage(adaptedInputs));
    }
  };

  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_form_main_container"
  }, /*#__PURE__*/React.createElement("div", {
    id: "raychat_form_header"
  }, userformStatus.success ? /*#__PURE__*/React.createElement("span", {
    className: "raychat_form_success_message"
  }, "\u0627\u0637\u0644\u0627\u0639\u0627\u062A \u0628\u0627 \u0645\u0648\u0641\u0642\u06CC\u062A \u062B\u0628\u062A \u0634\u062F.") : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_title font-bold"
  }, message.title ? message.title : ""), /*#__PURE__*/React.createElement("div", {
    className: "raychat_form_input_container"
  }, formInputs.map((item, index) => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_form_input_box font-regular"
  }, /*#__PURE__*/React.createElement("input", {
    type: item.type,
    className: "input",
    placeholder: item.placeholder,
    name: item.title,
    onChange: e => handleUserInput(e.target.name, e.target.value)
  })), item.error.active && /*#__PURE__*/React.createElement("span", {
    className: "input_error"
  }, item.error.message))), /*#__PURE__*/React.createElement("div", {
    className: "raychat_form_btn_container"
  }, Object.keys(userformStatus).length === 0 ? /*#__PURE__*/React.createElement("button", {
    disabled: disableSubmit,
    className: "font-bold",
    onClick: () => handleSendForm()
  }, "\u062B\u0628\u062A") : /*#__PURE__*/React.createElement("span", {
    className: "raychat_form_faild_message"
  }, userformStatus.message))))), /*#__PURE__*/React.createElement("img", {
    className: "raychat_operator_avatar",
    src: message.avatar ? message.avatar.includes("http") ? `${message.avatar}` : `${RAYCHAT_MAIN_URL}/${message.avatar}` : coverIcon
  })));
};

export default /*#__PURE__*/React.memo(ChatForm);