import React from "react";
import FileUpload from "../fileUpload/FileUpload";
import EmojiSender from "../emojiSender/EmojiSender";
import Styles from "./styles/chatInput";
import VoiceRecorder from "../voiceRecorder/VoiceRecorder";
import { useSelector } from "react-redux";
import SendMessage from "../sendMessage/SendMessage";
import { useEffect } from "react";
import { useState } from "react";

const mapState = ({
  messagesData,
  widgetData
}) => ({
  userInput: messagesData.messages.userInput,
  voiceRecording: messagesData.messages.voiceRecording,
  disableInput: messagesData.messages.disableInput,
  recordingAudio: messagesData.messages.recordingAudio,
  disableSendVoice: widgetData.widgetInfo.disableSendVoice
});

const ChatInput = /*#__PURE__*/React.forwardRef(({
  toggleIcons,
  onChange,
  onKeyDown
}, ref) => {
  const {
    userInput,
    voiceRecording,
    disableInput,
    recordingAudio,
    disableSendVoice
  } = useSelector(mapState);
  const [audioStream, setAudioStream] = useState(null);
  useEffect(async () => {
    if (!disableSendVoice) {
      const stream = await navigator.mediaDevices.getUserMedia({
        audio: true
      });
      setAudioStream(stream);
    }
  }, [disableSendVoice]);
  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_chat_input_container"
  }, disableInput.status ? /*#__PURE__*/React.createElement("span", {
    className: "raychat_input_message font-bold"
  }, disableInput.description) : /*#__PURE__*/React.createElement(React.Fragment, null, !userInput && !disableSendVoice && audioStream ? /*#__PURE__*/React.createElement(VoiceRecorder, {
    stream: audioStream
  }) : /*#__PURE__*/React.createElement(SendMessage, {
    userInput: userInput,
    onClick: () => onKeyDown()
  }), !voiceRecording ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("input", {
    type: "text",
    value: userInput,
    className: "raychat_chat_input",
    placeholder: "\u0627\u06CC\u0646\u062C\u0627 \u062A\u0627\u06CC\u067E \u06A9\u0646\u06CC\u062F...",
    onChange: onChange,
    onKeyDown: onKeyDown,
    ref: ref,
    id: "user_input"
  }), /*#__PURE__*/React.createElement(FileUpload, null), /*#__PURE__*/React.createElement(EmojiSender, {
    toggleIcons: toggleIcons
  })) : /*#__PURE__*/React.createElement(React.Fragment, null))));
});
export default /*#__PURE__*/React.memo(ChatInput);