import React from "react";
import { useState } from "react";
import { useEffect, useRef } from "react";
import { useDispatch } from "react-redux";
import { sendFileMessage, sendMessage, setRecordingAudio, setVoiceRecording } from "../../../redux/messages/messages.actions";
import Styles from "./styles/voiceRecorder";
import { useSelector } from "react-redux";
import AudioAnalyser from "../../audioAnalyser/AudioAnalyser";
import { useStopwatch } from "react-timer-hook";
import { IMAGES_BASE_URL } from "../../../utils/urls";

const mapState = ({
  messagesData
}) => ({
  recordingAudio: messagesData.messages.recordingAudio
});

const VoiceRecorder = ({
  stream
}) => {
  const {
    recordingAudio
  } = useSelector(mapState);
  const [mediaRecorder, setMediaRecorder] = useState();
  const [chunks, setChunks] = useState([]);
  const [audioStream, setAudioStream] = useState(null);
  const dispatch = useDispatch();
  const {
    seconds,
    minutes,
    start,
    reset
  } = useStopwatch({
    autoStart: true
  });
  const canvas = useRef(null);
  useEffect(async () => {
    // const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
    console.log("sttttt", stream);
    setAudioStream(stream);
    setMediaRecorder(prev => {
      return new MediaRecorder(stream);
    });
    setChunks(prev => []);
  }, []);
  useEffect(() => {
    if (mediaRecorder) {
      mediaRecorder.ondataavailable = e => {
        if (e.data && e.data.size > 0) {
          setChunks(prev => {
            return [...prev, e.data];
          });
        }
      };
    }
  }, [mediaRecorder]);

  const startRecording = async e => {
    e.preventDefault();
    dispatch(setRecordingAudio(audioStream));

    if (mediaRecorder.state !== "recording") {
      setChunks(prev => []);
      mediaRecorder.start(10);
      dispatch(setVoiceRecording(true));
      start();
    }
  };

  const stopRecording = e => {
    e.preventDefault();
    dispatch(setRecordingAudio(null));

    if (mediaRecorder.state !== "inactive") {
      mediaRecorder.stop();
      dispatch(setVoiceRecording(false));
      reset();
      saveAudio();
    }
  };

  const saveAudio = () => {
    const blob = new Blob(chunks, {
      type: "audio/mpeg"
    });
    const file = new File([blob], "voice", {
      lastModified: new Date().getTime(),
      type: blob.type
    });
    dispatch(sendFileMessage(file));
  };

  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/mic.svg`,
    onMouseDown: e => startRecording(e),
    onMouseUp: e => stopRecording(e),
    onTouchStart: e => startRecording(e),
    onTouchEnd: e => stopRecording(e),
    className: "raychat_voice_recorder"
  }), recordingAudio && /*#__PURE__*/React.createElement("div", {
    className: "raychat_voice_analyser_container"
  }, /*#__PURE__*/React.createElement(AudioAnalyser, {
    audio: recordingAudio
  }), /*#__PURE__*/React.createElement("div", {
    className: "raychat_voice_analyser_timer"
  }, `${minutes}:${seconds}`)));
};

export default /*#__PURE__*/React.memo(VoiceRecorder);