import React from "react";
import { useSelector } from "react-redux";
import { useDispatch } from "react-redux";
import { setSendingFile, uploadFile } from "../../redux/messages/messages.actions";
import Styles from "./styles/fileOverlay";
import SendMessage from "../chatInput/sendMessage/SendMessage";
import { IMAGES_BASE_URL } from "../../utils/urls";

const mapState = ({
  messagesData
}) => ({
  sendingFile: messagesData.messages.sendingFile
});

const FileOverlay = props => {
  const {
    sendingFile
  } = useSelector(mapState);
  const dispatch = useDispatch();

  const getSendingFileComponent = fileInfo => {
    switch (fileInfo.type) {
      case "audio":
        return /*#__PURE__*/React.createElement("audio", {
          controls: true
        }, /*#__PURE__*/React.createElement("source", {
          src: fileInfo.fileData,
          type: "audio/ogg"
        }), /*#__PURE__*/React.createElement("source", {
          src: fileInfo.fileData,
          type: "audio/mpeg"
        }));
        break;

      case "image":
        return /*#__PURE__*/React.createElement("div", {
          className: "img_container"
        }, /*#__PURE__*/React.createElement("img", {
          src: fileInfo.fileData,
          className: "img_message"
        }));
        break;

      case "file":
        return /*#__PURE__*/React.createElement("div", {
          className: "file_message_container"
        }, /*#__PURE__*/React.createElement("img", {
          className: "file_icon",
          src: `${IMAGES_BASE_URL}/file.svg`
        }), /*#__PURE__*/React.createElement("div", {
          className: "file_description"
        }, `${sendingFile.file.type}-${sendingFile.size}`));
        break;

      case "compress":
        return /*#__PURE__*/React.createElement("div", {
          className: "file_message_container"
        }, /*#__PURE__*/React.createElement("img", {
          className: "file_icon",
          src: `${IMAGES_BASE_URL}/file-zip.svg`
        }), /*#__PURE__*/React.createElement("div", {
          className: "file_description"
        }, `${sendingFile.file.type}-${sendingFile.size}`));
        break;

      case "video":
        return /*#__PURE__*/React.createElement("video", {
          src: fileInfo.fileData
        });
        break;

      default:
        break;
    }
  };

  const sendFileMessage = () => {
    dispatch(uploadFile(sendingFile));
    dispatch(setSendingFile(null));
  };

  const closeOverlay = () => {
    dispatch(setSendingFile(null));
  };

  return sendingFile ? /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_file_overlay_header"
  }, /*#__PURE__*/React.createElement("span", null, sendingFile.name), /*#__PURE__*/React.createElement("div", {
    className: "raychat_file_overlay_header_close_icon",
    onClick: () => closeOverlay()
  }, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/close.svg`
  }))), /*#__PURE__*/React.createElement("div", {
    className: "raychat_file_overlay_main"
  }, getSendingFileComponent(sendingFile), /*#__PURE__*/React.createElement("div", {
    className: "raychat_file_overlay_send_icon_container"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_file_overlay_send_icon"
  }, /*#__PURE__*/React.createElement(SendMessage, {
    onClick: () => sendFileMessage()
  })), /*#__PURE__*/React.createElement("span", {
    className: "font-bold"
  }, "\u0627\u0631\u0633\u0627\u0644")))) : /*#__PURE__*/React.createElement(React.Fragment, null);
};

export default FileOverlay;