import React from "react";
import Styles from "./styles/operatorMessage";
import emoji from "react-easy-emoji";
import { IMAGES_BASE_URL, RAYCHAT_MAIN_URL } from "../../../utils/urls";
import { useSelector } from "react-redux";

const mapStates = ({
  widgetData
}) => ({
  coverIcon: widgetData.widgetInfo.data.coverIcon
});

const OperatorMessage = ({
  withAvatar,
  message
}) => {
  const {
    coverIcon
  } = useSelector(mapStates);

  const getProperMessage = message => {
    const getFileType = fileName => {
      let array = fileName.split(".");
      return array[array.length - 1].toUpperCase();
    };

    switch (message.type) {
      case "text":
        return /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_message_content "
        }, emoji(message.content));
        break;

      case "emoji":
        return /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_emoji_message"
        }, emoji(message.content));
        break;

      case "audio":
        return /*#__PURE__*/React.createElement("audio", {
          controls: true
        }, /*#__PURE__*/React.createElement("source", {
          src: message.url,
          type: "audio/ogg"
        }), /*#__PURE__*/React.createElement("source", {
          src: message.url,
          type: "audio/mpeg"
        }), "Your browser does not support the audio tag.");
        break;

      case "image":
        return /*#__PURE__*/React.createElement("a", {
          target: "blank",
          href: message.url
        }, /*#__PURE__*/React.createElement("img", {
          src: message.url,
          className: "raychat_operator_img_message"
        }));
        break;

      case "file":
        return /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_file_message"
        }, /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_file_type_container text-purple"
        }, getFileType(message.name)), /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_file_info"
        }, /*#__PURE__*/React.createElement("span", null, message.name), /*#__PURE__*/React.createElement("span", {
          className: "raychat_operator_file_size"
        }, `${message.size} ${getFileType(message.name)}`)), /*#__PURE__*/React.createElement("a", {
          target: "blank",
          href: message.url
        }, /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_download_file_container"
        }, /*#__PURE__*/React.createElement("img", {
          src: `${IMAGES_BASE_URL}/downloa-file.svg`
        }))));
        break;

      case "compress":
        return /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_file_message"
        }, /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_file_type_container text-purple"
        }, getFileType(message.name)), /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_file_info"
        }, /*#__PURE__*/React.createElement("span", null, message.name), /*#__PURE__*/React.createElement("span", {
          className: "raychat_operator_file_size"
        }, `${message.size} ${getFileType(message.name)}`)), /*#__PURE__*/React.createElement("a", {
          target: "blank",
          href: message.url
        }, /*#__PURE__*/React.createElement("div", {
          className: "raychat_operator_download_file_container"
        }, /*#__PURE__*/React.createElement("img", {
          src: `${IMAGES_BASE_URL}/downloa-file.svg`
        }))));
        break;

      case "video":
        return /*#__PURE__*/React.createElement("video", {
          src: message.fileData
        });
        break;

      default:
        break;
    }
  };

  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_operator_text_message"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_operator_avatar_container"
  }, withAvatar && /*#__PURE__*/React.createElement("img", {
    className: "raychat_operator_avatar",
    src: message.avatar ? message.avatar.includes("http") ? `${message.avatar}` : `${RAYCHAT_MAIN_URL}/${message.avatar}` : coverIcon
  })), getProperMessage(message)));
};

export default OperatorMessage;