import React from "react";
import Styles from "./styles/greeting";
import { useSelector } from "react-redux";
import { useEffect } from "react";
import messageAudio from "../../../assets/sounds/mixkit-message-pop-alert-2354.mp3";
import { useDispatch } from "react-redux";
import { setLuancherContent, setShowLuancher, setShowTrigger } from "../../../redux/widget/widget.actions";
import { sendMessage, sendNewTypedWord, setUserInput } from "../../../redux/messages/messages.actions";
import SendMessage from "../../../components/chatInput/sendMessage/SendMessage";
import { IMAGES_BASE_URL, RAYCHAT_MAIN_URL } from "../../../utils/urls";

const mapState = ({
  widgetData,
  messagesData
}) => ({
  triggerData: widgetData.widgetInfo.data.trigger,
  showTrigger: widgetData.widgetInfo.showTrigger,
  userInput: messagesData.messages.userInput,
  operators: widgetData.widgetInfo.data.operators,
  coverIcon: widgetData.widgetInfo.data.coverIcon
});

const Greeting = props => {
  const {
    triggerData,
    showTrigger,
    userInput,
    operators,
    coverIcon
  } = useSelector(mapState);
  const dispatch = useDispatch();

  const handleUserInput = e => {
    dispatch(setUserInput(e.target.value));
  };

  const sendNewMessage = e => {
    if (userInput && userInput !== "") {
      const tmpId = Math.random().toString(36).substring(7);
      const newMessage = {
        content: userInput,
        me: true,
        type: "text",
        status: "pending",
        tmpId
      };
      dispatch(sendMessage(newMessage));
      dispatch(setUserInput(""));
    }
  };

  const handleKeyDown = e => {
    if (!e || e && e.key === "Enter") {
      sendNewMessage(e);
    }

    if (!e || e.key === " " || e.key === "Spacebar") {
      dispatch(sendNewTypedWord(userInput));
    }
  };

  const handleClickGreeting = () => {
    dispatch(setShowLuancher(true));
    dispatch(setLuancherContent("firstChat"));
  };

  useEffect(() => {
    if (triggerData.activeMessage) {
      dispatch(setShowTrigger(true));
    }
  }, [triggerData.activeMessage]);
  useEffect(() => {
    if (triggerData.activeMessage && !triggerData.activeMessage.mute && showTrigger) {
      let raychat_audio_sound = new Audio(messageAudio);
      raychat_audio_sound.play();
    }
  }, [showTrigger]);
  return showTrigger && triggerData.activeMessage ? /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_greeting_container"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_greeting"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_greeting_actions",
    onClick: e => {
      e.preventDefault();
      dispatch(setShowTrigger(false));
    }
  }, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/close.svg`,
    className: "raychat_close_greeting"
  })), /*#__PURE__*/React.createElement("div", {
    className: "raychat_greeting_message_container",
    onClick: () => handleClickGreeting()
  }, /*#__PURE__*/React.createElement("p", null, triggerData.activeMessage.message)), /*#__PURE__*/React.createElement("div", {
    className: "raychat_greeting_input_container"
  }, /*#__PURE__*/React.createElement("input", {
    type: "text",
    value: userInput,
    className: "raychat_greeting_input font-regular",
    placeholder: "\u0627\u06CC\u0646\u062C\u0627 \u062A\u0627\u06CC\u067E \u06A9\u0646\u06CC\u062F...",
    onChange: e => handleUserInput(e),
    onKeyDown: e => handleKeyDown(e),
    id: "user_input"
  }), /*#__PURE__*/React.createElement("div", {
    className: "raychat_greeting_send_icon_container"
  }, /*#__PURE__*/React.createElement(SendMessage, {
    onClick: e => sendNewMessage(e),
    className: "raychat_greeting_send_icon"
  })))), /*#__PURE__*/React.createElement("img", {
    className: "raychat_greeting_greeting_avatar",
    src: triggerData.activeMessage.avatar ? `${RAYCHAT_MAIN_URL}/${triggerData.activeMessage.avatar}` : coverIcon
  }))) : /*#__PURE__*/React.createElement(React.Fragment, null);
};

export default Greeting;