import React, { useRef, useEffect, useState } from "react";
import Styles from "./styles/header";
import { useDispatch, useSelector } from "react-redux";
import { setLuancherContent, setShowLuancher } from "../../../../../redux/widget/widget.actions";
import { IMAGES_BASE_URL, RAYCHAT_MAIN_URL } from "../../../../../utils/urls";

const mapState = ({
  widgetData
}) => ({
  headerExpand: widgetData.widgetInfo.headerExpand,
  coverIcon: widgetData.widgetInfo.data.coverIcon
});

const Header = ({
  agentInfo
}) => {
  const dispatch = useDispatch();
  const {
    headerExpand,
    coverIcon
  } = useSelector(mapState);
  const [descriptionHeight, setDEscriptionHeight] = useState(null);

  const handleCloseLuancher = () => {
    dispatch(setShowLuancher(false));
  };

  let desc = useRef(null);
  useEffect(() => {
    if (desc.current) {
      const childHeightRaw = desc.current.clientHeight;

      if (childHeightRaw) {
        const childHeight = `${childHeightRaw / 16}rem`;
        setDEscriptionHeight(childHeight);
      }
    }
  }, []);
  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    id: "accepted_chat_header",
    className: `raychat_accepted_chat_header_container ${headerExpand && "expanded"}`
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_header"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_operator_info"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_avatar_container"
  }, /*#__PURE__*/React.createElement("img", {
    src: `${agentInfo.avatar ? agentInfo.avatar.includes("http") ? agentInfo.avatar : `${RAYCHAT_MAIN_URL}/${agentInfo.avatar}` : coverIcon}`
  })), /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_agent_info"
  }, /*#__PURE__*/React.createElement("span", {
    className: "raychat_accepted_chat_agent_name font-bold"
  }, agentInfo.name), /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_agent_avatar_container font-regular"
  }, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/online.svg`
  }), /*#__PURE__*/React.createElement("span", {
    className: "raychat_accepted_chat_agent font-regular"
  }, "\u0686\u0646\u062F \u0633\u0627\u0639\u062A")))), /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_actions"
  }, /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_close_icon",
    onClick: () => handleCloseLuancher()
  }, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/close.svg`
  })), /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_back_icon",
    onClick: () => dispatch(setLuancherContent("conversationsList"))
  }, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/arrow-ios-back-outline.svg`
  })))), /*#__PURE__*/React.createElement("div", {
    className: "raychat_accepted_chat_header_description_container",
    ref: desc,
    style: {
      maxHeight: headerExpand ? descriptionHeight : 0,
      transition: "0.4s max-height"
    }
  }, /*#__PURE__*/React.createElement("span", {
    className: "raychat_accepted_chat_agnet_position font-bold"
  }, agentInfo.title), /*#__PURE__*/React.createElement("span", {
    className: "font-regular"
  }, "9:23am \u062F\u0631 \u062A\u0647\u0631\u0627\u0646.\u0627\u06CC\u0631\u0627\u0646"), /*#__PURE__*/React.createElement("p", {
    className: "raychat_accepted_chat_header_description font-regular"
  }, "\u062F\u0631 \u0627\u06CC\u0646 \u0642\u0633\u0645\u062A \u062A\u0648\u0636\u06CC\u062D\u0627\u062A\u06CC \u062A\u0648\u0633\u0637 \u0627\u067E\u0631\u0627\u062A\u0648\u0631 \u062F\u0631 \u0645\u0648\u0631\u062F \u062E\u0648\u062F\u0634 \u0646\u0648\u0634\u062A\u0647 \u0645\u06CC\u200C\u0634\u0648\u062F \u06A9\u0647 \u0645\u06CC\u062A\u0648\u0627\u0646 \u062E\u0627\u0644\u06CC \u0646\u06CC\u0632 \u0628\u0627\u0634\u062F.\u062D\u062F\u0627\u06A9\u062B\u0631 \u0645\u06CC\u062A\u0648\u0627\u0646\u062F \u06F1\u06F5\u06F0 \u06A9\u0627\u0631\u0627\u06A9\u062A\u0631 \u0628\u0627\u0634\u062F. \u062F\u0631 \u0627\u06CC\u0646 \u0642\u0633\u0645\u062A \u0627\u06CC\u0646\u062A\u0631 \u0647\u0627 \u062D\u0630\u0641 \u0645\u06CC\u200C\u0634\u0648\u062F."))));
};

export default Header;