import React, { useState, useEffect } from "react";
import ChatInput from "../../../../../components/chatInput/index/ChatInput";
import Header from "../header/Header";
import Messags from "../messages/Messags";
import EmojiPicker from "../../../../../components/chatInput/emojiPicker/EmojiPicker";
import Styles from "./styles/firstChat";
import { useDispatch } from "react-redux";
import { sendMessage, sendNewTypedWord, setUserInput } from "../../../../../redux/messages/messages.actions";
import { useSelector } from "react-redux";
import { IMAGES_BASE_URL } from "../../../../../utils/urls";

const mapState = ({
  messagesData,
  widgetData
}) => ({
  userInput: messagesData.messages.userInput,
  agents: messagesData.agents,
  hideRaychatLogo: widgetData.widgetInfo.hideRaychatLogo
});

const FirstChat = ({
  changeLuncherContent
}) => {
  const [showIcons, setShowIcons] = useState(false);
  const {
    userInput,
    hideRaychatLogo
  } = useSelector(mapState);
  const dispatch = useDispatch();
  const textInput = /*#__PURE__*/React.createRef();

  const toggleIcons = () => {
    setShowIcons(!showIcons);
  };

  const handleUserInput = e => {
    dispatch(setUserInput(e.target.value));
  };

  const sendNewMessage = e => {
    if (userInput && userInput !== "") {
      const tmpId = Math.random().toString(36).substring(7);
      const newMessage = {
        content: userInput,
        me: true,
        type: "text",
        status: "pending",
        tmpId
      };
      dispatch(sendMessage(newMessage));
      dispatch(setUserInput(""));
      textInput.current.focus();
    }
  };

  const handleSelectEmoji = e => {
    if (userInput && userInput !== "") {
      dispatch(setUserInput(userInput + e.target.alt));
      textInput.current?.focus();
    } else {
      const tmpId = Math.random().toString(36).substring(7);
      const newEmojiMessage = {
        content: e.target.alt,
        me: true,
        type: "emoji",
        status: "pending",
        tmpId
      };
      dispatch(sendMessage(newEmojiMessage));
      setShowIcons(false);
    }
  };

  const handleKeyDown = e => {
    if (!e || e && e.key === "Enter") {
      sendNewMessage(e);
    }

    if (!e || e.key === " " || e.key === "Spacebar") {
      dispatch(sendNewTypedWord(userInput));
    }
  };

  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    className: "raychat_messaging_page"
  }, /*#__PURE__*/React.createElement(Header, null), /*#__PURE__*/React.createElement(Messags, null), /*#__PURE__*/React.createElement("div", {
    className: "raychat_messaging_page_footer"
  }, !hideRaychatLogo && /*#__PURE__*/React.createElement("div", {
    className: "powered_by_raychet"
  }, /*#__PURE__*/React.createElement("div", {
    className: "main_powered_by_raychat_div"
  }, /*#__PURE__*/React.createElement("a", {
    href: "https://raychat.io/?utm_source=https://raychat.io&utm_campaign=referralPoweredBy&utm_medium=widget&ref=SybnrMe0pG&PBUI=true",
    target: "_blank",
    id: "powerByImage"
  }, "\u0642\u062F\u0631\u062A \u06AF\u0631\u0641\u062A\u0647 \u0627\u0632 \u0631\u0627\u06CC\u0686\u062A", /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/logo.svg`,
    id: "powerByImageTag"
  })))), /*#__PURE__*/React.createElement("div", {
    className: "raychat_messaging_page_chat_input_container"
  }, /*#__PURE__*/React.createElement(ChatInput, {
    onChange: e => handleUserInput(e),
    onKeyDown: e => handleKeyDown(e) // value={userInput}
    ,
    toggleIcons: toggleIcons,
    ref: textInput
  }))), showIcons && /*#__PURE__*/React.createElement(EmojiPicker, {
    onClick: e => {
      handleSelectEmoji(e);
    }
  })));
};

export default /*#__PURE__*/React.memo(FirstChat);