import React from "react";
import ChatForm from "../../../../../components/chatForm/ChatForm";
import Rating from "../../../../../components/rating/Rating";
import Comment from "../../../../../components/comment/Comment";
import { useSelector } from "react-redux";
import OperatorMessage from "../../../../../components/textMessage/operatorMessage/OperatorMessage";
import UserMessage from "../../../../../components/textMessage/userMessage/UserMessage";
import { useEffect } from "react";
import { useDispatch } from "react-redux";
import { fetchMoreMessagesStart, setNewMessage } from "../../../../../redux/messages/messages.actions";
import StatusMessage from "../../../../../components/statusMessage/StatusMessage";
import { setHeaderExpand } from "../../../../../redux/widget/widget.actions";
import Styles from "./styles/messages";

const mapState = ({
  messagesData,
  widgetData
}) => ({
  forms: widgetData.widgetInfo.data.forms,
  messages: messagesData.messages.data,
  fetchMoreMessages: messagesData.messages.fetchMoreMessages,
  widgetData: widgetData,
  headerExpand: widgetData.widgetInfo.headerExpand
});

const Messags = props => {
  const {
    messages,
    forms,
    widgetData,
    fetchMoreMessages,
    headerExpand
  } = useSelector(mapState);
  const dispatch = useDispatch();

  const getOperatorMessage = (message, index) => {
    if (message.type === "form") {
      return /*#__PURE__*/React.createElement(ChatForm, {
        message: message
      });
    } else if (message.type === "comment") {
      return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Comment, {
        message: message
      }), /*#__PURE__*/React.createElement(Rating, {
        message: message
      }));
    } else {
      return /*#__PURE__*/React.createElement(OperatorMessage, {
        withAvatar: messages[index - 1] && (messages[index - 1].me || messages[index - 1].me === null) ? true : false,
        message: message
      });
    }
  };

  const getChatMessage = (message, index) => {
    if (message.me) {
      return /*#__PURE__*/React.createElement(UserMessage, {
        message: message
      });
    } else if (message.me === false) {
      return getOperatorMessage(message, index);
    } else if (message.me === null) {
      return /*#__PURE__*/React.createElement(StatusMessage, {
        message: message
      });
    }
  };

  useEffect(() => {
    const element = document.getElementById("messages_container");

    if (element) {
      element.scrollTop = element.scrollHeight - element.clientHeight;
    }
  }, [messages]);
  useEffect(() => {
    if (headerExpand && fetchMoreMessages.status) {
      dispatch(fetchMoreMessagesStart(fetchMoreMessages.page));
    }
  }, [headerExpand]);

  const handleScroll = e => {
    const element = e.target;

    if (element.scrollTop == 0 && element.clientHeight < element.scrollHeight) {
      dispatch(setHeaderExpand(true));
    } else {
      dispatch(setHeaderExpand(false));
    }
  };

  return /*#__PURE__*/React.createElement(Styles, {
    onScroll: e => {
      handleScroll(e);
    },
    id: "messages_container"
  }, messages.map((message, index) => getChatMessage(message, index)));
};

export default /*#__PURE__*/React.memo(Messags);