import React, { useState } from "react";
import launcherIcon from "../../../../assets/images/logo-no-bg.svg";
import Cover from "../cover/Cover";
import ConversationsList from "../conversationsList/main/ConversationsList";
import FirstChat from "../firstChat/main/FistChat";
import AcceptedChat from "../acceptedChat/main/AcceptedChat";
import Greeting from "../../greeting/Greeting";
import Styles from "./styles/luancher";
import { useSelector } from "react-redux";
import { useDispatch } from "react-redux";
import { setAnimateWidget, setShowLuancher } from "../../../../redux/widget/widget.actions";
import { useMediaQuery } from "react-responsive";
import Div100vh from "react-div-100vh";
import { useEffect } from "react";
import CloseIcon from "../../../../components/icons/CloseIcon";
import { IMAGES_BASE_URL } from "../../../../utils/urls";

const mapState = ({
  widgetData,
  messagesData
}) => ({
  showLuancher: widgetData.widgetInfo.showLuancher,
  animateWidget: widgetData.widgetInfo.animateWidget,
  luancherInfo: widgetData.widgetInfo.luancherInfo,
  widgetSleepMode: widgetData.widgetInfo.widgetSleepMode
});

const Luancher = props => {
  const smallWidth = useMediaQuery({
    query: "(max-width: 700px)"
  });
  const {
    showLuancher,
    luancherInfo,
    animateWidget,
    widgetSleepMode
  } = useSelector(mapState);
  const dispatch = useDispatch();

  const handleClick = () => {
    dispatch(setShowLuancher(!showLuancher));
  };

  const MessageCount = props => {
    if (props.count === 0 || props.isOpen === true) {
      return null;
    }

    return /*#__PURE__*/React.createElement("div", {
      className: "raychat_sc_new_messsages_count"
    }, props.count);
  };

  const classList = [showLuancher ? "raychat_luancher_opened" : "", "raychat_luancher_centered"];
  let chatClassList = ["raychat_sc_chat_window", "animate__animated animate__fadeIn", showLuancher ? "raychat_luancher_opened" : "raychat_luancher_closed"];
  const luancherClassList = ["raychat_sc_launcher", "raychat_luancher_centered", showLuancher && smallWidth ? "raychat_luancher_hidden" : "", animateWidget && "animate__animated animate__flip"];

  const getLuancherContent = () => {
    return /*#__PURE__*/React.createElement(React.Fragment, null, luancherInfo.content === "cover" && /*#__PURE__*/React.createElement(Cover, null), luancherInfo.content === "acceptedChat" && /*#__PURE__*/React.createElement(AcceptedChat, {
      isOpen: showLuancher,
      onClose: () => handleClick()
    }), luancherInfo.content === "conversationsList" && /*#__PURE__*/React.createElement(ConversationsList, null), luancherInfo.content === "firstChat" && /*#__PURE__*/React.createElement(FirstChat, null));
  };

  var storedWidth = 0;
  var storedHeight = 0;

  const getLuancher = () => {
    return /*#__PURE__*/React.createElement(React.Fragment, null, smallWidth ? /*#__PURE__*/React.createElement(Div100vh, {
      className: "raychat_luancher_main_container"
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        height: "100%"
      },
      className: (showLuancher ? "raychat_luancher_opened" : "raychat_luancher_closed", chatClassList.join(" "))
    }, getLuancherContent())) : /*#__PURE__*/React.createElement("div", {
      className: chatClassList.join(" ")
    }, getLuancherContent()));
  };

  useEffect(() => {
    const animationRoot = document.getElementById("animation-root");
    animationRoot.addEventListener("animationend", () => {
      dispatch(setAnimateWidget(false));
    });
  }, []);
  return /*#__PURE__*/React.createElement(Styles, null, /*#__PURE__*/React.createElement("div", {
    id: "animation-root",
    className: luancherClassList.join(" ")
  }, /*#__PURE__*/React.createElement("div", {
    className: classList.join(" "),
    onClick: () => handleClick()
  }, /*#__PURE__*/React.createElement(MessageCount, {
    count: luancherInfo.newMessagesCount,
    isOpen: showLuancher
  }), showLuancher ? /*#__PURE__*/React.createElement("div", {
    className: "animate__animated animate__rotateIn sc-open-icon"
  }, /*#__PURE__*/React.createElement("img", {
    src: `${IMAGES_BASE_URL}/close.svg`
  })) : /*#__PURE__*/React.createElement("img", {
    className: "animate__animated animate__rotateIn sc-closed-icon",
    src: widgetSleepMode ? launcherIcon : luancherInfo.icon ? luancherInfo.icon : launcherIcon
  }))), /*#__PURE__*/React.createElement(Greeting, null), showLuancher && getLuancher());
};

export default Luancher;