import { messageTypes } from "./messages.types";
export const INITIAL_STATE = {
  messages: {
    loading: false,
    userInput: "",
    sendingFile: null,
    voiceRecording: false,
    recordingAudio: null,
    offlineMessage: {
      sendStatus: false,
      beforeSendingMessage: false,
      forceGetUserDetails: false,
      message: null
    },
    fetchMoreMessages: {
      status: false,
      page: 0
    },
    disableInput: {
      status: false,
      discription: ""
    },
    data: []
  },
  agents: [],
  userformStatus: {},
  browserInfo: {},
  departments: {
    loading: false,
    activeDepartment: null,
    data: []
  },
  acceptedChat: {
    status: false,
    agentInfo: null
  }
};

const messagesReducer = (state = INITIAL_STATE, action) => {
  switch (action.type) {
    // case "FETCH":
    //   return {
    //     ...state,
    //   };
    //   break;
    case messageTypes.SET_NEW_MESSAGE:
      return { ...state,
        messages: { ...state.messages,
          data: [...state.messages.data, action.payload]
        }
      };
      break;

    case messageTypes.SEND_MESSAGE:
      return { ...state,
        messages: { ...state.messages,
          data: [...state.messages.data, action.payload]
        }
      };
      break;

    case messageTypes.FETCH_DEPARTMENTS_START:
      return { ...state,
        departments: { ...state.departments,
          loading: true
        }
      };
      break;

    case messageTypes.SET_DEPARTMENTS:
      return { ...state,
        department: {
          loading: false,
          data: action.payload
        }
      };
      break;

    case messageTypes.SET_ACTIVE_DEPARTMENT:
      return { ...state,
        departments: { ...state.departments,
          activeDepartment: action.payload
        }
      };
      break;

    case messageTypes.SET_ACCEPTED_CHAT:
      return { ...state,
        acceptedChat: { ...action.payload
        }
      };
      break;

    case messageTypes.SET_MESSAGE_STATUS:
      let {
        status,
        message_id
      } = action.payload;
      let adaptedMessages = state.messages.data.map(message => {
        if (message.tmpId === message_id) {
          return { ...message,
            status: status
          };
        } else {
          return message;
        }
      });
      return { ...state,
        messages: { ...state.messages,
          data: adaptedMessages
        }
      };
      break;

    case messageTypes.SET_FORM_MESSAGE:
      return { ...state,
        messages: { ...state.messages,
          data: [...state.messages.data, action.payload]
        }
      };
      break;

    case messageTypes.SET_USER_INPUT:
      return { ...state,
        messages: { ...state.messages,
          userInput: action.payload
        }
      };
      break;

    case messageTypes.SET_SENDING_FILE:
      return { ...state,
        messages: { ...state.messages,
          sendingFile: action.payload
        }
      };
      break;

    case messageTypes.SET_VOICE_RECORDING:
      return { ...state,
        messages: { ...state.messages,
          voiceRecording: action.payload
        }
      };
      break;

    case messageTypes.SET_USER_FORM_STATUS:
      return { ...state,
        userformStatus: action.payload
      };
      break;

    case messageTypes.SET_FETCH_MORE_MESSAGES:
      return { ...state,
        messages: { ...state.messages,
          fetchMoreMessages: action.payload
        }
      };
      break;

    case messageTypes.SET_OLD_MESSAGES:
      return { ...state,
        messages: { ...state.messages,
          data: [...action.payload, ...state.messages.data]
        }
      };
      break;

    case messageTypes.SET_AGENTS:
      return { ...state,
        agents: action.payload
      };
      break;

    case messageTypes.SET_DISABLE_INPUT:
      return { ...state,
        messages: { ...state.messages,
          disableInput: action.payload
        }
      };
      break;

    case messageTypes.SET_RECORDING_AUDIO:
      return { ...state,
        messages: { ...state.messages,
          recordingAudio: action.payload
        }
      };
      break;

    case messageTypes.SET_COMMENT_RESPONSE:
      let messages = state.messages.data.map(message => {
        if (message.type === "comment") {
          return { ...message,
            sendStatus: { ...message.sendStatus,
              [action.payload.box]: {
                success: action.payload.success,
                message: action.payload.message
              }
            }
          };
        } else {
          return message;
        }
      });
      return { ...state,
        messages: { ...state.messages,
          data: messages
        }
      };
      break;

    case messageTypes.SET_BROWSER:
      return { ...state,
        browserInfo: action.payload
      };
      break;

    case messageTypes.SET_OFFLINE_MESSAGE:
      return { ...state,
        messages: { ...state.messages,
          offlineMessage: action.payload
        }
      };
      break;

    case messageTypes.UPDATE_ACCEPTED_CHAT_AVATAR:
      return { ...state,
        acceptedChat: { ...state.acceptedChat,
          agentInfo: { ...state.acceptedChat.agentInfo,
            avatar: action.payload
          }
        }
      };
      break;

    default:
      return state;
  }
};

export default messagesReducer;