import { all, call, put, takeLatest } from "redux-saga/effects";
import { handleFetchDepartment } from "./messages.helper";
import { messageTypes } from "./messages.types";
import io from "socket.io-client";
import { eventChannel } from "redux-saga";
import { fork, take, cancel } from "redux-saga/effects";
import { setChatStatus, setNewMessage, setFormMessage, setAcceptedChat, setSendingFile, setUserFormStatus, setFetchMoreMessages, setOldMessages, setAgents, setDisableInput, setCommentResponse, setBrowser, setOffilneMessage, updateAcceptedChatAvatar } from "./messages.actions";
import { select } from "redux-saga/effects";
import { raychat_local_storage, checkForVisitorDetails, checkForNewVisitor, sendNewMessage, createFormMessage, createOperatorMessage, createAcceptedStatusMessage, createClosedStatusMessage, getAcceptedChatInfo, createTriggerMessage, raychat_open_verify, createFileMessage, uploadFile, submitUserDetailsForm, sendNewWord, fetchMessages, addNewComment, getWidetSettings, updateAgentAvatar } from "./messages.adapter";
import { fetchWidgetInfoStart, setActiveTriggerMessage, setDepartment, setDisableSendVoice, setDisableTrigger, setDisableTriggerMessages, setHideRaychatLogo, setLuancherIcon, setOfficeHoure } from "../widget/widget.actions";
import { setMessageStatus } from "./messages.actions";
import { handleFetchWidgetInfo } from "../widget/widget.helper";
import { setWidgetInfo, setShowWidget } from "../widget/widget.actions";
import { createWidgetInfoObject } from "../widget/widget.adapter";
import { combineReducers } from "redux";
import { fetchWidgetInfo } from "../widget/widget.sagas";
import messageAudio from "../../assets/sounds/mixkit-message-pop-alert-2354.mp3";
import { IMAGES_BASE_URL, RAYCHAT_SOCKET_URL } from "../../utils/urls";

const getWidgetInfo = state => {
  return {
    container_id: state.widgetData.widgetInfo.data.channel.containerId,
    channel_id: state.widgetData.widgetInfo.data.channel.id,
    widget_info: state.widgetData.widgetInfo.data,
    activeMessage: state.messagesData.messages.activeMessage,
    activeDepartment: state.messagesData.departments.activeDepartment,
    isOfficeHoure: state.widgetData.widgetInfo.isOfficeHoure,
    forms: state.widgetData.widgetInfo.data.forms
  };
};

var socket;
var acceptedChat = {};
var isFirstChat;
export function* fetchDepartment({
  payload
}) {
  try {
    const {
      channel_id
    } = payload;
    const returnedData = yield handleFetchDepartment(channel_id);
    yield put(setDepartment(returnedData.data));
  } catch (error) {
    console.log(error);
  }
}
export function* onFetchDepartmentsStart() {
  yield takeLatest(messageTypes.FETCH_DEPARTMENTS_START, fetchDepartment);
}

function connect() {
  const socket = io(RAYCHAT_SOCKET_URL, {
    reconnectionDelayMax: 10000,
    transports: ["websocket"],
    path: "/socket.io",
    query: {
      type: "widget",
      token: "0dbfd679-66f2-466d-9b03-f5363610aef8"
    },
    autoConnect: true
  });
  return new Promise(resolve => {
    socket.on("connect", () => {
      resolve(socket);
    });
  });
}

function subscribe(socket) {
  return eventChannel(emit => {
    socket.on("acceptedChat", res => {
      emit(setNewMessage(createAcceptedStatusMessage(res)));
      acceptedChat = getAcceptedChatInfo(res);
      emit(setAcceptedChat(acceptedChat));
    });
    socket.on("conversationClosed", res => {
      emit(setNewMessage(createClosedStatusMessage(res))); // if (acceptedChat.status) {

      emit(setNewMessage({
        me: false,
        type: "comment",
        sendStatus: {
          emotion: {
            success: false,
            message: null
          },
          message: {
            success: false,
            message: null
          }
        }
      })); // }
    });
    socket.on("showFormAndMessage", res => {
      emit(setNewMessage(createFormMessage(res)));

      if (res.offlineMessage.form.forceGetUserDetails == true) {
        emit(setDisableInput({
          status: true,
          description: "لطفا اطلاعات فرم را وارد کنید. "
        }));
      }
    });
    socket.on("typing", res => {
      console.log("typing", res);
    });
    socket.on("raychat_newMessage", res => {
      emit(setNewMessage(createOperatorMessage(res)));
      emit(setActiveTriggerMessage(createTriggerMessage(res)));
      emit(updateAcceptedChatAvatar(res.agent_avatar));
      updateAgentAvatar(res.agent_avatar);
      let raychat_audio_sound = new Audio(messageAudio);
      raychat_audio_sound.play();
    });
    return () => {};
  });
}

function* read(socket) {
  const channel = yield call(subscribe, socket);

  while (true) {
    let action = yield take(channel);
    yield put(action);
  }
}

function* sendTextMessage({
  payload
}) {
  const message = payload;
  const response = yield new Promise(resolve => {
    sendNewMessage(socket, message).then(data => {
      if (data.tmpId && data.status !== 2) {// let t = { status: "seen", message_id: response.tmpId };
        // yield put(setMessageStatus(t));
        // const messagecontainer = document.getElementById(data.tmpId);
        // if (messagecontainer) {
        //   const img = messagecontainer.querySelector(
        //     ".raychat_user_status_icon"
        //   );
        //   img.src = `${IMAGES_BASE_URL}/seenMessage.svg`;
        // }
      }

      resolve(data);
    });
  });

  if (response.tmpId && response.status !== 2) {
    let t = {
      status: "seen",
      message_id: response.tmpId
    };
    yield put(setMessageStatus(t));
  }

  if (response.status === 2) {
    let {
      forms
    } = yield select(getWidgetInfo);
    yield put(setNewMessage(createFormMessage({
      offlineMessage: forms
    })));

    if (forms.form.forceGetUserDetails == true) {
      yield put(setDisableInput({
        status: true,
        description: "لطفا اطلاعات فرم را وارد کنید. "
      }));
    }
  }
}

function* sendFileMessage({
  payload
}) {
  let file = payload;
  let fileMessage = raychat_open_verify(file);
  yield put(setSendingFile(fileMessage));
}

function* uploadFileMessage({
  payload
}) {
  let {
    file,
    fileType,
    fileData,
    type
  } = payload;
  let {
    widget_info
  } = yield select(getWidgetInfo);

  if (payload) {
    const fileMessage = createFileMessage(payload);
    yield put(setNewMessage(fileMessage));
    const response = yield new Promise(resolve => {
      uploadFile(file, fileType, fileData, fileMessage.tmpId, socket, widget_info.channel.token).then(data => {
        // if (response.tmpId) {
        // let t = { status: "seen", message_id: response.tmpId };
        // yield put(setMessageStatus(t));
        //   const messagecontainer = document.getElementById(response.tmpId);
        //   if (messagecontainer) {
        //     const img = messagecontainer.querySelector(
        //       ".raychat_user_status_icon"
        //     );
        //     img.src = `${IMAGES_BASE_URL}/seenMessage.svg`;
        //   }
        // }
        resolve(data);
      });
    });

    if (response.tmpId) {
      let t = {
        status: "seen",
        message_id: response.tmpId
      };
      yield put(setMessageStatus(t));
    }

    if (response === "showForm") {
      let {
        forms
      } = yield select(getWidgetInfo);
      yield put(setNewMessage(createFormMessage({
        offlineMessage: forms
      })));

      if (forms.form.forceGetUserDetails == true) {
        yield put(setDisableInput({
          status: true,
          description: "لطفا اطلاعات فرم را وارد کنید. "
        }));
      }
    }
  }
}

function* sendFormMessage({
  payload
}) {
  const response = yield new Promise(resolve => {
    submitUserDetailsForm(socket, payload).then(data => {
      resolve(data);
    });
  });
  const sendFormStatus = {
    success: response.success,
    message: response.success ? "اطلاعات با موفقیت ثبت شد!" : "اطلاعات با موفقیت ثبت نشد!"
  };
  yield put(setUserFormStatus(sendFormStatus));

  if (response.success) {
    yield put(setDisableInput({
      status: false,
      description: ""
    }));
  }
}

function* sendNewTypedWord({
  payload
}) {
  const message = payload;
  sendNewWord(socket, message);
}

function* fetchMoreMessages({
  payload
}) {
  const page = payload;
  const response = yield new Promise(resolve => {
    fetchMessages(socket, page).then(data => {
      resolve(data);
    });
  });

  if (response.length > 0) {
    yield put(setOldMessages(response));
    yield put(setFetchMoreMessages({
      status: true,
      page: page + 1
    }));
  } else {
    yield put(setFetchMoreMessages({
      status: false,
      page: 0
    }));
  }
}

function* addComment({
  payload
}) {
  const comment = payload;
  const response = yield new Promise(resolve => {
    addNewComment(socket, comment).then(data => {
      resolve(data);
    });
  });
  let {
    message,
    box,
    success
  } = response;
  yield put(setCommentResponse({
    message,
    box,
    success
  }));
}

function* write(socket) {
  // while (true) {
  yield takeLatest(messageTypes.SEND_MESSAGE, sendTextMessage);
  yield takeLatest(messageTypes.SEND_FILE_MESSAGE, sendFileMessage);
  yield takeLatest(messageTypes.UPLOAD_FILE, uploadFileMessage);
  yield takeLatest(messageTypes.SEND_FOMR_MESSAGE, sendFormMessage);
  yield takeLatest(messageTypes.TYPE_NEW_WORD, sendNewTypedWord);
  yield takeLatest(messageTypes.FETCH_MORE_MESSAGES_START, fetchMoreMessages);
  yield takeLatest(messageTypes.ADD_COMMENT, addComment); // sendTextMessage(socket, message);
  // sendFileMessage(socket, file);
  // }
}

function* handleIO(socket) {
  yield fork(read, socket);
  yield fork(write, socket);
}

const getFormFields = fields => {
  switch (fields) {
    case "name":
      return ["fullName"];
      break;

    case "email":
      return ["email"];
      break;

    case "phone":
      return ["phone"];
      break;

    case "both":
      return ["email", "phone"];
      break;

    case "allThree":
      return ["fullName", "email", "phone"];
      break;

    default:
      break;
  }
};

const createOfflineFormMessage = (form, offlineMessage) => {
  let title = offlineMessage.active ? offlineMessage.message : "";
  let formMessage = {
    title,
    me: false,
    type: "form",
    fields: getFormFields(form.fieldName),
    avatar: ""
  };
  return formMessage;
};

function* tackeNotOfficeHourActions(notOfficeHoure) {
  let offlineMessage = notOfficeHoure.offlineMessage;
  let form = offlineMessage.form;
  let formMessage;

  if (isFirstChat && offlineMessage.active && form && form.fieldName) {
    formMessage = createOfflineFormMessage(form, offlineMessage.offlineMessage);

    if (form.beforeSendingMessage) {
      yield put(setNewMessage(formMessage));
    }

    if (form.forceGetUserDetails == true) {
      yield put(setDisableInput({
        status: true,
        description: "لطفا اطلاعات فرم را وارد کنید. "
      }));
    }
  }

  if (notOfficeHoure.hideWidget == "true") {
    yield put(setShowWidget(false));
  }
}

function* flow() {
  let widgetResponse = yield call(fetchWidgetInfo);
  let widgetInfo = widgetResponse.data;
  isFirstChat = localStorage.getItem("rayToken") ? false : true;

  if (widgetResponse.status) {
    let {
      acceptedChat
    } = yield select(getWidgetInfo);
    let {
      channel_id,
      container_id,
      widget_info,
      isOfficeHoure,
      forms
    } = yield select(getWidgetInfo);

    if (!isOfficeHoure) {
      yield call(tackeNotOfficeHourActions, widgetInfo.notOfficeHours.notOfficeHoure);
    }

    raychat_local_storage.init();
    socket = yield call(connect);
    const widgetSettinges = yield new Promise(resolve => {
      getWidetSettings(socket, channel_id).then(data => {
        resolve(data);
      });
    });
    console.log(widgetSettinges);

    if (widgetSettinges.hideRaychatLogo) {
      yield put(setHideRaychatLogo(true));
    } else {
      yield put(setHideRaychatLogo(false));
    }

    if (!widgetSettinges.sendVoiceWidget) {
      yield put(setDisableSendVoice(true));
    } else {
      yield put(setDisableSendVoice(false));
    }

    setTimeout(() => {
      checkForVisitorDetails(socket, channel_id, container_id);
    }, 2000);
    const response = yield new Promise(resolve => {
      checkForNewVisitor(socket, widget_info, channel_id, container_id, forms).then(data => {
        resolve(data);
      });
    });
    yield put(setAgents(response.agents));
    yield put(setBrowser(response.browser));

    if (response.messages && Array.isArray(response.messages)) {
      for (let i = 0; i < response.messages.length; i++) {
        yield put(setNewMessage(response.messages[i]));
      }

      if (response.chatCount && response.chatCount > response.messages.length) {
        yield put(setFetchMoreMessages({
          status: true,
          page: 1
        }));
      }
    }

    if (response.forceGetUserDetails == true) {
      yield put(setDisableInput({
        status: true,
        description: "لطفا اطلاعات فرم را وارد کنید. "
      }));
    }

    if (response.openConversation && response.openConversationAgent) {
      const agent = {
        name: response.openConversationAgent.agent,
        title: response.openConversationAgent.raychat_agent_title,
        avatar: response.openConversationAgent.raychat_agent_avatar
      };
      acceptedChat = {
        status: true,
        agentInfo: agent
      };
      yield put(setAcceptedChat(acceptedChat));
    } // while (true) {


    const t = yield fork(handleIO, socket); // }
  }
}

export default function* messageSagas() {
  yield all([call(onFetchDepartmentsStart), call(flow)]);
}