import { detectOs } from "../../utils/browser";
import { RAYCHAT_DEPARTMENT_URL, RAYCHAT_LOGO_URL, RAYCHAT_MAIN_URL } from "../../utils/urls";
import { raycaht_shuffle_array } from "../messages/messages.adapter";

const getWidgetPosition = (coordinates, directions) => {
  let adaptedCoordinates = {};
  let directionsArray = directions.split(" ");
  directionsArray.forEach(direction => {
    for (let key in coordinates) {
      if (key.includes(direction.trim())) {
        adaptedCoordinates[key] = coordinates[key];
        delete coordinates[key];
      } else {
        adaptedCoordinates[key] = "auto";
      }
    }
  });
  return adaptedCoordinates;
};

const getRandomNumber = (min, max) => {
  return Math.floor(Math.random() * (max - min + 1)) + min;
};

const getConditionTime = condition => {
  switch (condition.eq) {
    case "==":
      return condition.value;
      break;

    case "<=":
      return getRandomNumber(1, condition.value);
      break;

    case ">=":
      return getRandomNumber(condition.value, condition.value + 30);
      break;

    case "<":
      return getRandomNumber(1, condition.value - 1);
      break;

    case ">":
      return getRandomNumber(condition.value + 1, condition.value + 30);
      break;

    default:
      break;
  }
};

const getWidgetTrigger = triggerItems => {
  let adaptedTrigger = [];
  let triggerTimes = {};
  let maxTime = 0;
  let conditionIndex = 0;
  let rayToken = localStorage.getItem("rayToken");
  triggerItems.forEach((item, index) => {
    let showOnce = item.justOnce;
    let {
      mobile
    } = detectOs();

    if (item.enabled === "true" && (!showOnce || showOnce && !rayToken) && (mobile && item.mobile !== false || !mobile)) {
      adaptedTrigger.push(item);
      item.conditions.forEach((condition, index) => {
        if (condition.cond === "1") {
          triggerTimes[conditionIndex] = getConditionTime(condition);
          conditionIndex++;
        }
      });
    }
  });

  for (let key in triggerTimes) {
    if (Number(triggerTimes[key]) > maxTime) {
      maxTime = Number(triggerTimes[key]);
    }
  }

  return {
    messages: adaptedTrigger,
    times: triggerTimes,
    maxTime: maxTime
  };
};

const getLogo = personalize => {
  switch (personalize.logo) {
    case "1":
      return `${RAYCHAT_LOGO_URL}/raychat-logo-main.svg`;
      break;

    case "2":
      return `${RAYCHAT_LOGO_URL}/raychat-logo-eye-smile.svg`;
      break;

    case "3":
      return `${RAYCHAT_LOGO_URL}/raychat-logo-sleep.svg`;
      break;

    case "4":
      return `${RAYCHAT_LOGO_URL}/main-logo-dots.svg`;
      break;

    case "5":
      return `${RAYCHAT_LOGO_URL}/raychat-logo-small-dots.svg`;
      break;

    case "6":
      return `${RAYCHAT_LOGO_URL}/raychat-logo-official.svg`;
      break;

    case "7":
      return `${RAYCHAT_LOGO_URL}/121.png`;
      break;

    case "8":
      return `${RAYCHAT_LOGO_URL}/121.png`;

    default:
      break;
  }
};

export const getLuancherIcon = (packType, personalize) => {
  if (packType === "professional" || packType === "free") {
    return getLogo(personalize);
  } else if (packType === "commerical" || packType === "premium") {
    if (personalize.isCustomLogo && personalize.logo === "7") {
      return `${RAYCHAT_MAIN_URL}/${personalize.isCustomLogo}`;
    } else {
      return getLogo(personalize);
    }
  }
};
export const getShowWidgetStataus = personalizeData => {
  let {
    mobile
  } = detectOs();

  if (mobile && !personalizeData.loadInPhone) {
    return false;
  } else {
    return true;
  }
};

const getTimeDetailes = time => {
  let adaptedTime = {};
  let timeArray = time.split("");
  adaptedTime.hour = Number(`${timeArray[0]}${timeArray[1]}`);
  adaptedTime.minute = Number(`${timeArray[timeArray.length - 2]}${timeArray[timeArray.length - 1]}`);
  return adaptedTime;
};

const getCurrentDate = async date => {
  try {
    return new Date(new Date(date.split(".")[0]));
  } catch (error) {
    console.error(error);
  }
};

export const checkIfOfficeHour = async (officeHours, date) => {
  let currentDate = await getCurrentDate(date);
  let weekday = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
  let isOfficeHour = false;
  let currentWeekDay = weekday[currentDate.getDay()];
  let isWorkDay = currentWeekDay === "Friday" ? false : true;

  if (officeHours) {
    officeHours.forEach(item => {
      if (item.key === currentWeekDay || (item.key === "workDays" || item.key === "entireWeek") && isWorkDay) {
        let currentTime = {
          hour: currentDate.getHours(),
          minute: currentDate.getMinutes()
        };
        let startTime = getTimeDetailes(item.from);
        let endTime = getTimeDetailes(item.to);

        if (currentTime.hour > startTime.hour && currentTime.hour < endTime.hour) {
          isOfficeHour = true;
        }
      }
    });
  } else {
    isOfficeHour = true;
  }

  if (officeHours && officeHours.length === 0) {
    isOfficeHour = true;
  }

  return isOfficeHour;
};

const getWidgetOperators = (operators, icon) => {
  console.log("icon", icon);
  let adaptedOperators = [];
  operators.forEach(operator => {
    if (operator.meta.avatar) {
      console.log("meta", operator.meta.avatar);
      adaptedOperators.push(operator);
    } else {
      console.log("noooooo");
      adaptedOperators.push({ ...operator,
        meta: { ...operator.meta,
          avatar: icon
        }
      });
    }
  });
  return adaptedOperators;
};

export const createWidgetInfoObject = async apiResponse => {
  let adaptedObject = { ...apiResponse,
    operators: raycaht_shuffle_array(apiResponse.operators),
    personalize: { ...apiResponse.personalize.data.personalize,
      position: getWidgetPosition(apiResponse.personalize.data.personalize.position, apiResponse.personalize.data.personalize.positionb)
    },
    channel: { ...apiResponse.channel,
      packType: apiResponse.channel.package.type
    },
    operators: getWidgetOperators(apiResponse.operators, getLuancherIcon(apiResponse.channel.package.type, apiResponse.personalize.data.personalize))
  };
  let isOfficeHoure = await checkIfOfficeHour(adaptedObject.officeHours, apiResponse.date);
  let luancherIcon;
  adaptedObject.coverIcon = getLuancherIcon(adaptedObject.channel.packType, adaptedObject.personalize);

  if (!isOfficeHoure && adaptedObject.notOfficeHours.notOfficeHoure.disableTriggers == "true") {
    adaptedObject.trigger = {
      messages: [],
      times: {},
      maxTime: null
    };
  } else {
    adaptedObject.trigger = getWidgetTrigger(apiResponse.trigger);
  }

  if (!isOfficeHoure && adaptedObject.notOfficeHours.notOfficeHoure.sleepLogo == "true") {
    luancherIcon = `${RAYCHAT_LOGO_URL}/raychat-logo-sleep.svg`;
  } else {
    luancherIcon = adaptedObject.coverIcon;
  }

  let showWidget = getShowWidgetStataus(adaptedObject.personalize);
  return {
    data: adaptedObject,
    icon: luancherIcon,
    isOfficeHoure,
    showWidget
  };
};