import { widgetTypes } from "./widget.types";
export const INITIAL_STATE = {
  widgetInfo: {
    loading: false,
    data: null,
    showWidget: false,
    showLuancher: false,
    showTrigger: false,
    headerExpand: true,
    animateWidget: false,
    isOfficeHoure: false,
    disableTrigger: false,
    widgetSleepMode: false,
    hideRaychatLogo: true,
    disableSendVoice: true,
    department: {
      loading: false,
      data: null
    },
    luancherInfo: {
      icon: null,
      newMessagesCount: 0,
      content: "cover"
    }
  }
};

const widgetReducer = (state = INITIAL_STATE, action) => {
  switch (action.type) {
    case widgetTypes.FETCH_WIDGET_INFO_START:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          loading: true
        }
      };

    case widgetTypes.SET_WIDGET_INFO:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          loading: false,
          data: action.payload
        }
      };

    case widgetTypes.SET_ACTIVE_TRIGGER_MESSAGE:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          data: { ...state.widgetInfo.data,
            trigger: { ...state.widgetInfo.data.trigger,
              activeMessage: action.payload
            }
          }
        }
      };

    case widgetTypes.SET_SHOW_WIDGET:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          showWidget: action.payload
        }
      };

    case widgetTypes.SET_SHOW_LUANCHER:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          showLuancher: action.payload,
          showTrigger: action.payload ? false : state.widgetInfo.showTrigger
        }
      };

    case widgetTypes.SET_SHOW_TRIGGER:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          showTrigger: action.payload && !state.widgetInfo.showLuancher ? true : false
        }
      };

    case widgetTypes.SET_LUANCHER_CONTENT:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          luancherInfo: { ...state.widgetInfo.luancherInfo,
            content: action.payload
          }
        }
      };

    case widgetTypes.SET_LUANCHER_ICON:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          luancherInfo: { ...state.widgetInfo.luancherInfo,
            icon: action.payload
          }
        }
      };

    case widgetTypes.SET_HEADER_EXPAND:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          headerExpand: action.payload
        }
      };

    case widgetTypes.SET_ANIMATE_WIDGET:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          animateWidget: action.payload
        }
      };

    case widgetTypes.SET_OFFICE_HOURE:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          isOfficeHoure: action.payload
        }
      };

    case widgetTypes.SET_DISABLE_TRIGGER:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          disableTrigger: action.payload
        }
      };

    case widgetTypes.SET_WIDGET_SLEEP_MODE:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          widgetSleepMode: action.payload
        }
      };

    case widgetTypes.SET_DISABLE_TRIGGER_MESSAGES:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          data: { ...state.widgetInfo.data,
            trigger: { ...state.widgetInfo.data.trigger,
              messages: []
            }
          }
        }
      };

    case widgetTypes.SET_HIDE_RAYCHAT_LOGO:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          hideRaychatLogo: action.payload
        }
      };

    case widgetTypes.SET_DISABLE_SEND_VOICE:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          disableSendVoice: action.payload
        }
      };

    case widgetTypes.SET_DEPARTMENT:
      return { ...state,
        widgetInfo: { ...state.widgetInfo,
          department: {
            loading: false,
            data: action.payload
          }
        }
      };

    default:
      return state;
  }
};

export default widgetReducer;